https://git.reactos.org/?p=reactos.git;a=commitdiff;h=a0721ebdd33f7c32546edd3cfaf966c64860988c

commit a0721ebdd33f7c32546edd3cfaf966c64860988c
Author:     Hermès Bélusca-Maïto <[email protected]>
AuthorDate: Thu Nov 26 00:25:05 2020 +0100
Commit:     Hermès Bélusca-Maïto <[email protected]>
CommitDate: Thu Nov 26 00:29:34 2020 +0100

    [SMSS] Use the new IsNEC_98 macro defined for user-mode.
---
 base/system/smss/pagefile.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/base/system/smss/pagefile.c b/base/system/smss/pagefile.c
index 51429a18867..0e3b6746746 100644
--- a/base/system/smss/pagefile.c
+++ b/base/system/smss/pagefile.c
@@ -851,8 +851,8 @@ SmpCreateVolumeDescriptors(VOID)
     wcscpy(Buffer, L"\\??\\A:\\");
     RtlInitUnicodeString(&VolumePath, Buffer);
 
-    /* Start with the C drive except on weird Japanese NECs... */
-    StartChar = SharedUserData->AlternativeArchitecture ? L'A' : L'C';
+    /* Start with the C drive, except on NEC PC-98 */
+    StartChar = IsNEC_98 ? L'A' : L'C';
     for (Drive = StartChar, DriveDiff = StartChar - L'A'; Drive <= L'Z'; 
Drive++, DriveDiff++)
     {
         /* Skip the disk if it's not in the drive map */

Reply via email to